pub async fn update_android_bootreason(
dir: Option<DirectoryProxy>,
android_provided_bootreason: Option<String>,
) -> Result<String, Error>Expand description
Update the Android bootreason.
Called only once when the Starnix kernel is initialized. If called more than once, it reports false Android crash cases to Pitot.